@@ -1,11 +1,11 @@
 import getpass
-QRGSe=object
-QRGSN=staticmethod
-QRGSl=False
-QRGSj=Exception
-QRGSP=None
-QRGSb=input
-QRGSs=list
+TDlcH=object
+TDlch=staticmethod
+TDlck=False
+TDlcd=Exception
+TDlcm=None
+TDlce=input
+TDlcn=list
 import json
 import logging
 import sys
@@ -13,29 +13,29 @@ from localstack.config import CONFIG_FILE_PATH,load_config_file
 from localstack.constants import API_ENDPOINT
 from localstack.utils.common import load_file,safe_requests,save_file,to_str
 LOG=logging.getLogger(__name__)
-class AuthProvider(QRGSe):
- @QRGSN
+class AuthProvider(TDlcH):
+ @TDlch
  def name():
   raise
  def get_or_create_token(self,username,password,headers):
   pass
  def get_user_for_token(self,token):
   pass
- @QRGSN
+ @TDlch
  def providers():
   return{c.name():c for c in AuthProvider.__subclasses__()}
- @QRGSN
- def get(provider,raise_error=QRGSl):
+ @TDlch
+ def get(provider,raise_error=TDlck):
   provider_class=AuthProvider.providers().get(provider)
   if not provider_class:
    msg='Unable to find auth provider class "%s"'%provider
    LOG.warning(msg)
    if raise_error:
-    raise QRGSj(msg)
-   return QRGSP
+    raise TDlcd(msg)
+   return TDlcm
   return provider_class()
 class AuthProviderInternal(AuthProvider):
- @QRGSN
+ @TDlch
  def name():
   return "internal"
  def get_or_create_token(self,username,password,headers):
@@ -46,28 +46,28 @@ class AuthProviderInternal(AuthProvider):
   try:
    result=json.loads(to_str(response.content or "{}"))
    return result["token"]
-  except QRGSj:
+  except TDlcd:
    pass
  def read_credentials(self,username):
   print("Please provide your login credentials below")
   if not username:
    sys.stdout.write("Username: ")
    sys.stdout.flush()
-   username=QRGSb()
+   username=TDlce()
   password=getpass.getpass()
   return username,password,{}
  def get_user_for_token(self,token):
-  raise QRGSj("Not implemented")
-def login(provider,username=QRGSP):
+  raise TDlcd("Not implemented")
+def login(provider,username=TDlcm):
  auth_provider=AuthProvider.get(provider)
  if not auth_provider:
-  providers=QRGSs(AuthProvider.providers().keys())
-  raise QRGSj('Unknown provider "%s", should be one of %s'%(provider,providers))
+  providers=TDlcn(AuthProvider.providers().keys())
+  raise TDlcd('Unknown provider "%s", should be one of %s'%(provider,providers))
  username,password,headers=auth_provider.read_credentials(username)
  print("Verifying credentials ... (this may take a few moments)")
  token=auth_provider.get_or_create_token(username,password,headers)
  if not token:
-  raise QRGSj("Unable to verify login credentials - please try again")
+  raise TDlcd("Unable to verify login credentials - please try again")
  configs=load_config_file()
  configs["login"]={"provider":provider,"username":username,"token":token}
  save_file(CONFIG_FILE_PATH,json.dumps(configs))
