@@ -1,12 +1,13 @@
 import base64
-ptcDa=True
-ptcDR=Exception
-ptcDk=False
-ptcDY=str
-ptcDG=len
-ptcDq=int
-ptcDM=range
-ptcDj=object
+fEAuB=None
+fEAuU=Exception
+fEAuj=True
+fEAun=str
+fEAuo=len
+fEAug=False
+fEAuz=int
+fEAud=range
+fEAuy=object
 import glob
 import json
 import logging
@@ -26,11 +27,21 @@ ENV_PREPARED={}
 MAX_KEY_CACHE_DURATION_SECS=60*60*24
 LOG=logging.getLogger(__name__)
 ENV_LOCALSTACK_API_KEY="LOCALSTACK_API_KEY"
-def read_api_key(raise_if_missing=ptcDa):
+TEST_AUTH_HEADERS=fEAuB
+class KeyActivationError(fEAuU):
+ def __init__(self,message:fEAun=fEAuB):
+  self.message=message
+class CachedKeyError(KeyActivationError):
+ pass
+class InvalidKeyError(KeyActivationError):
+ pass
+def read_api_key(raise_if_missing=fEAuj):
  key=(os.environ.get(ENV_LOCALSTACK_API_KEY)or "").strip()
  if not key and raise_if_missing:
-  raise ptcDR("Unable to retrieve API key. Please configure $%s in your environment"%ENV_LOCALSTACK_API_KEY)
+  raise fEAuU("Unable to retrieve API key. Please configure $%s in your environment"%ENV_LOCALSTACK_API_KEY)
  return key
+def truncate_api_key(api_key:fEAun):
+ return '"%s..."(%s)'%(api_key[:3],fEAuo(api_key))
 def fetch_key():
  api_key=read_api_key()
  if api_key=="test":
@@ -38,18 +49,23 @@ def fetch_key():
  data={"api_key":api_key,"version":__version__}
  try:
   logging.getLogger("py.warnings").setLevel(logging.ERROR)
-  result=requests.post("%s/activate"%config.API_URL,json.dumps(data),verify=ptcDk)
+  result=requests.post("%s/activate"%config.API_URL,json.dumps(data),verify=fEAug)
   if result.status_code>=400:
    content=result.content
    content_type=result.headers.get("Content-Type")
-   raise ptcDR('Received error activating key (code %s): ctype "%s" - %s'%(result.status_code,content_type,content))
+   if result.status_code==403:
+    message=json.loads(to_str(content))["message"]
+    raise InvalidKeyError("Activation key %s is invalid or expired! Reason: %s"%(truncate_api_key(api_key),message))
+   raise KeyActivationError('Received error activating key (code %s): ctype "%s" - %s'%(result.status_code,content_type,content))
   key_base64=json.loads(to_str(result.content))["key"]
   cache_key_locally(api_key,key_base64)
- except ptcDR as e:
+ except InvalidKeyError:
+  raise
+ except fEAuU as e:
   if log_license_issues():
-   api_key=ptcDY(api_key_configured()or "")
-   api_key_prefix=api_key[:3]
-   LOG.warning('Error activating API key "%s..."(%s): %s %s'%(api_key_prefix,ptcDG(api_key),e,traceback.format_exc()))
+   api_key=fEAun(api_key_configured()or "")
+   LOG.warning("Error activating API key %s: %s %s"%(truncate_api_key(api_key),e,traceback.format_exc()))
+   LOG.warning("Looking for cached key as fallback...")
   key_base64=load_cached_key(api_key)
  finally:
   logging.getLogger("py.warnings").setLevel(logging.WARNING)
@@ -57,25 +73,27 @@ def fetch_key():
  return decoded_key
 def cache_key_locally(api_key,key_b64):
  configs=localstack_config.load_config_file()
- timestamp=ptcDY(ptcDq(now_utc()))
+ timestamp=fEAun(fEAuz(now_utc()))
  key_raw=to_str(base64.b64decode(key_b64))
- for i in ptcDM(ptcDG(timestamp)):
+ for i in fEAud(fEAuo(timestamp)):
   key_raw=str_insert(key_raw,i*2,timestamp[i])
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
- configs["cached_key"]={"timestamp":ptcDq(timestamp),"key_hash":md5(api_key),"key":key_b64}
+ configs["cached_key"]={"timestamp":fEAuz(timestamp),"key_hash":md5(api_key),"key":key_b64}
  save_file(localstack_config.CONFIG_FILE_PATH,json.dumps(configs))
  return configs
 def load_cached_key(api_key):
  configs=localstack_config.load_config_file()
- cached_key=configs["cached_key"]
+ cached_key=configs.get("cached_key")
+ if not cached_key:
+  raise CachedKeyError("Could not find cached key")
  if cached_key.get("key_hash")!=md5(api_key):
-  raise ptcDR("Cached key was created for a different API key")
+  raise CachedKeyError("Cached key was created for a different API key")
  now=now_utc()
  if(now-cached_key["timestamp"])>MAX_KEY_CACHE_DURATION_SECS:
-  raise ptcDR("Cached key expired")
- timestamp=ptcDY(cached_key["timestamp"])
+  raise CachedKeyError("Cached key expired")
+ timestamp=fEAun(cached_key["timestamp"])
  key_raw=to_str(base64.b64decode(cached_key["key"]))
- for i in ptcDM(ptcDG(timestamp)):
+ for i in fEAud(fEAuo(timestamp)):
   assert key_raw[i]==timestamp[i]
   key_raw=str_remove(key_raw,i)
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
@@ -104,6 +122,8 @@ def decrypt_files(key):
    decrypt_file(f,target,key)
  parallelize(_decrypt,files)
 def cleanup_environment():
+ if not localstack_config.is_in_docker:
+  return
  excepted_files=r".*/services/((edge)|(dns_server)|(__init__))\.py"
  for folder in PROTECTED_FOLDERS:
   for subpath in("*.py.enc","**/*.py.enc"):
@@ -113,50 +133,60 @@ def cleanup_environment():
      for delete_file in(target,"%sc"%target):
       if os.path.exists(delete_file):
        os.remove(delete_file)
+def check_require_pro():
+ if config.REQUIRE_PRO:
+  LOG.error("Unable to activate API key, but $REQUIRE_PRO is configured - quitting.")
+  sys.exit(1)
 def prepare_environment():
- class OnClose(ptcDj):
+ class OnClose(fEAuy):
   def __exit__(self,*args,**kwargs):
    if not ENV_PREPARED.get("finalized"):
     cleanup_environment()
-   ENV_PREPARED["finalized"]=ptcDa
+   ENV_PREPARED["finalized"]=fEAuj
   def __enter__(self,*args,**kwargs):
    pass
  if not ENV_PREPARED.get("finalized"):
   try:
    key=fetch_key()
    if not key:
-    raise ptcDR("Unable to fetch and validate API key from environment")
+    raise fEAuU("Unable to fetch and validate API key from environment")
    if key!="test":
     decrypt_files(key)
     LOG.info("Successfully activated API key")
    else:
     LOG.info("Using test API key")
    os.environ[ENV_PRO_ACTIVATED]="1"
-  except ptcDR as e:
+  except KeyActivationError as e:
+   if log_license_issues():
+    LOG.warning(e.message)
+   check_require_pro()
+  except fEAuU as e:
    if log_license_issues():
     LOG.warning("Unable to activate API key: %s %s"%(e,traceback.format_exc()))
-   if config.REQUIRE_PRO:
-    LOG.error("Unable to activate API key, but $REQUIRE_PRO is configured - quitting.")
-    sys.exit(1)
+   check_require_pro()
  return OnClose()
 def log_license_issues():
- return api_key_configured()and localstack_config.is_env_true("LOG_LICENSE_ISSUES")
+ return api_key_configured()and localstack_config.is_env_not_false("LOG_LICENSE_ISSUES")
 def api_key_configured():
- return read_api_key(raise_if_missing=ptcDk)
+ return read_api_key(raise_if_missing=fEAug)
 def is_logged_in():
  configs=localstack_config.load_config_file()
  login_info=configs.get("login")
  if not login_info:
-  return ptcDk
- return ptcDa
+  return fEAug
+ return fEAuj
 def get_auth_headers():
+ if TEST_AUTH_HEADERS:
+  return TEST_AUTH_HEADERS
  configs=localstack_config.load_config_file()
  login_info=configs.get("login")
- if not login_info:
-  raise ptcDR("Please log in first")
- auth_token=login_info["token"]
- if not auth_token.startswith("%s "%login_info["provider"]):
-  auth_token="%s %s"%(login_info["provider"],auth_token)
- headers={"authorization":auth_token}
- return headers
+ if login_info:
+  auth_token=login_info["token"]
+  if not auth_token.startswith("%s "%login_info["provider"]):
+   auth_token="%s %s"%(login_info["provider"],auth_token)
+  return{"authorization":auth_token}
+ api_key=read_api_key(raise_if_missing=fEAug)
+ if api_key:
+  return{"ls-api-key":api_key,"ls-version":__version__}
+ raise fEAuU("Please log in first")
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
