@@ -1,26 +1,26 @@
 #!/usr/bin/env python
-exThi=dict
-exThj=super
-exThg=hasattr
-exThV=Exception
-exThv=object
-exThn=dir
-exThl=None
-exThK=False
-exThW=True
-exThF=len
-exThz=set
+HNWYX=dict
+HNWYE=super
+HNWYp=hasattr
+HNWYo=Exception
+HNWYR=object
+HNWYc=dir
+HNWYM=None
+HNWYa=False
+HNWYB=True
+HNWYA=len
+HNWYd=set
 import errno
 import socket
 from select import select
 from socket import(AF_INET,AF_INET6,IPPROTO_IPV6,IPPROTO_TCP,IPV6_V6ONLY,SO_REUSEADDR,SOCK_STREAM,SOL_SOCKET,TCP_NODELAY)
-class AttrDict(exThi):
+class AttrDict(HNWYX):
  def __init__(self,*args,**kwargs):
-  exThj(AttrDict,self).__init__(*args,**kwargs)
+  HNWYE(AttrDict,self).__init__(*args,**kwargs)
   self.__dict__=self
 def tcp_listen(six,addr,port,blk):
  s=socket.socket(AF_INET6 if six else AF_INET,SOCK_STREAM)
- if six and exThg(socket,"IPV6_V6ONLY"):
+ if six and HNWYp(socket,"IPV6_V6ONLY"):
   s.setsockopt(IPPROTO_IPV6,IPV6_V6ONLY,0)
  s.setsockopt(SOL_SOCKET,SO_REUSEADDR,1)
  s.setsockopt(IPPROTO_TCP,TCP_NODELAY,1)
@@ -37,9 +37,9 @@ def tcp_connect(six,addr,port,blk):
 def safe_close(x):
  try:
   x.close()
- except exThV:
+ except HNWYo:
   pass
-class Server(exThv):
+class Server(HNWYR):
  def __init__(self,opt,q):
   self.opt=opt
   self.sock=tcp_listen(opt.ip6,opt.bind_addr,opt.bind_port,0)
@@ -51,17 +51,17 @@ class Server(exThv):
    cl,addr=self.sock.accept()
    cl.setblocking(0)
    self.q.append(Proxy(self.opt,cl,addr))
-class Half(exThv):
- def __init__(self,opt,sock,addr,exThn):
+class Half(HNWYR):
+ def __init__(self,opt,sock,addr,HNWYc):
   self.opt=opt
   self.sock=sock
   self.addr=addr
-  self.exThn=exThn
-  self.name="peer" if self.exThn else "client"
+  self.HNWYc=HNWYc
+  self.name="peer" if self.HNWYc else "client"
   self.queue=[]
-  self.dest=exThl
-  self.err=exThl
-  self.ready=exThK
+  self.dest=HNWYM
+  self.err=HNWYM
+  self.ready=HNWYa
  def pre_wait(self,rr,r,w,e):
   if self.ready:
    rr.append(self.sock)
@@ -72,7 +72,7 @@ class Half(exThv):
   if not self.err and self.sock in w and self.queue:
    self.write_some()
   if not self.err and self.sock in r:
-   self.ready=exThW
+   self.ready=HNWYB
    self.copy()
   return self.err
  def error(self,msg,e):
@@ -81,9 +81,9 @@ class Half(exThv):
  def write_some(self):
   try:
    n=self.sock.send(self.queue[0])
-  except exThV as e:
+  except HNWYo as e:
    return self.error("send error",e)
-  if n!=exThF(self.queue[0]):
+  if n!=HNWYA(self.queue[0]):
    self.queue[0]=self.queue[0][n:]
   else:
    del self.queue[0]
@@ -92,17 +92,17 @@ class Half(exThv):
    buf=self.sock.recv(4096)
   except socket.error as e:
    if e.errno==errno.EWOULDBLOCK:
-    self.ready=exThK
+    self.ready=HNWYa
     return
    return self.error("recv socket error",e)
-  except exThV as e:
+  except HNWYo as e:
    return self.error("recv error",e)
-  if exThF(buf)==0:
+  if HNWYA(buf)==0:
    return self.error("eof",0)
   self.dest.queue.append(buf)
  def close(self):
   safe_close(self.sock)
-class Proxy(exThv):
+class Proxy(HNWYR):
  def __init__(self,opt,sock,addr):
   self.opt=opt
   self.cl=Half(opt,sock,addr,"i")
@@ -110,7 +110,7 @@ class Proxy(exThv):
   self.peer=Half(opt,peer,addr,"o")
   self.cl.dest=self.peer
   self.peer.dest=self.cl
-  self.err=exThl
+  self.err=HNWYM
  def pre_wait(self,rr,r,w,e):
   self.cl.pre_wait(rr,r,w,e)
   self.peer.pre_wait(rr,r,w,e)
@@ -125,7 +125,7 @@ class Proxy(exThv):
   return self.err
 def server_loop(opt):
  qs=[]
- opt["ip6"]=opt.get("ip6",exThK)
+ opt["ip6"]=opt.get("ip6",HNWYa)
  opt["bind_addr"]=opt.get("bind_addr","0.0.0.0")
  opt["addr"]=opt.get("addr","127.0.0.1")
  opt["bind_port"]=opt.get("bind_port",0)
@@ -137,15 +137,15 @@ def server_loop(opt):
    q.pre_wait(rr,r,w,e)
   timeo=10.0 if not rr else 0.0
   r,w,e=select(r,w,e,timeo)
-  r=exThz(r).union(rr)
+  r=HNWYd(r).union(rr)
   for q in qs:
    if q.post_wait(r,w,e):
     qs.remove(q)
 def main():
- opt={"ip6":exThK,"bind_port":2223,"addr":"192.168.43.191","port":22}
- opt={"ip6":exThK,"bind_port":48429,"addr":"128.0.100.3","port":22}
- opt={"ip6":exThK,"port":54237,"bind_addr":"128.0.100.2","bind_port":22}
- opt={"ip6":exThK,"port":54237,"bind_addr":"192.168.100.3","bind_port":22}
+ opt={"ip6":HNWYa,"bind_port":2223,"addr":"192.168.43.191","port":22}
+ opt={"ip6":HNWYa,"bind_port":48429,"addr":"128.0.100.3","port":22}
+ opt={"ip6":HNWYa,"port":54237,"bind_addr":"128.0.100.2","bind_port":22}
+ opt={"ip6":HNWYa,"port":54237,"bind_addr":"192.168.100.3","bind_port":22}
  server_loop(opt)
 if __name__=="__main__":
  main()
