@@ -4,7 +4,7 @@ import re
 from localstack import config as localstack_config
 from localstack import constants as localstack_constants
 from localstack.constants import LOCALHOST_HOSTNAME
-from localstack.utils.docker import DOCKER_CLIENT
+from localstack.utils.docker_utils import DOCKER_CLIENT
 
 FALSE_STRINGS = localstack_constants.FALSE_STRINGS
 
@@ -60,6 +60,10 @@ BIGDATA_HOST_FROM_MAIN = (os.environ.get("BIGDATA_HOST_FROM_MAIN") or "").strip(
 # will resolve to the real DNS entry, rather than the local one.
 DNS_LOCAL_NAME_PATTERNS = (os.environ.get("DNS_LOCAL_NAME_PATTERNS") or "").strip()
 
+# whether to transparently set the target endpoint (by passing $AWS_ENDPOINT_URL) in
+#  AWS SDK clients used in user code (e.g., Lambdas). default: true
+TRANSPARENT_LOCAL_ENDPOINTS = localstack_config.is_env_not_false("TRANSPARENT_LOCAL_ENDPOINTS")
+
 # whether to use static ports and IDs (e.g., cf-<port>) for CloudFormation distributions
 CLOUDFRONT_STATIC_PORTS = localstack_config.is_env_true("CLOUDFRONT_STATIC_PORTS")
 
@@ -100,6 +104,12 @@ PORT_AZURE = 12121
 # add default service ports (TODO needed?)
 localstack_constants.DEFAULT_SERVICE_PORTS["azure"] = PORT_AZURE
 
+# name of cloud pod to sync state with (e.g., used during CI runs)
+SYNC_POD_NAME = os.environ.get("SYNC_POD_NAME") or ""
+SYNC_POD_VERSION = None
+# name of CI project to sync usage events and state with
+CI_PROJECT = os.environ.get("CI_PROJECT") or ""
+
 # Docker host name resolvable from containers
 DOCKER_HOST_NAME = "host.docker.internal"
 
@@ -135,22 +145,25 @@ if localstack_config.DOCKER_HOST_FROM_CONTAINER == DOCKER_HOST_NAME:
 
 # update variable names that need to be passed as arguments to Docker
 localstack_config.CONFIG_ENV_VARS += [
-    "SMTP_HOST",
-    "SMTP_USER",
-    "SMTP_PASS",
-    "SMTP_EMAIL",
-    "DNS_SERVER",
-    "DNS_ADDRESS",
-    "ENFORCE_IAM",
-    "DNS_RESOLVE_IP",
-    "DNS_LOCAL_NAME_PATTERNS",
     "AUTOSTART_UTIL_CONTAINERS",
-    "CLOUDFRONT_STATIC_PORTS",
-    "REQUIRE_PRO",
     "AZURE",
     "BIGDATA_DOCKER_FLAGS",
-    "LOG_LICENSE_ISSUES",
+    "CI_PROJECT",
+    "CLOUDFRONT_STATIC_PORTS",
+    "DNS_ADDRESS",
+    "DNS_LOCAL_NAME_PATTERNS",
+    "DNS_RESOLVE_IP",
+    "DNS_SERVER",
+    "ENFORCE_IAM",
     "KUBE_ENDPOINT",
+    "LOG_LICENSE_ISSUES",
+    "REQUIRE_PRO",
+    "SMTP_EMAIL",
+    "SMTP_HOST",
+    "SMTP_PASS",
+    "SMTP_USER",
+    "SYNC_POD_NAME",
+    "TRANSPARENT_LOCAL_ENDPOINTS",
 ]
 
 # re-initialize configs in localstack
