@@ -1,9 +1,9 @@
 from localstack.services.cloudformation.service_models import GenericBaseModel
-TGEug=staticmethod
-TGEuV=None
+NohJK=staticmethod
+NohJy=None
 from localstack.utils.aws import aws_stack
 class ApiGatewayAuthorizer(GenericBaseModel):
- @TGEug
+ @NohJK
  def cloudformation_type():
   return "AWS::ApiGateway::Authorizer"
  def fetch_state(self,stack_name,resources):
@@ -13,7 +13,7 @@ class ApiGatewayAuthorizer(GenericBaseModel):
   auth_uri=self.resolve_refs_recursively(stack_name,props.get("AuthorizerUri"),resources)
   authorizers=client.get_authorizers(restApiId=api_id,limit=200)["items"]
   result=[a for a in authorizers if a["type"]==props.get("Type")and a.get("authorizerUri")==auth_uri]
-  return(result or[TGEuV])[0]
+  return(result or[NohJy])[0]
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("id")
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
