@@ -1,10 +1,10 @@
 import json
-aftWx=staticmethod
-aftWC=str
-aftWL=None
-aftWT=int
-aftWY=Exception
-aftWj=list
+aRSmz=staticmethod
+aRSme=str
+aRSmB=None
+aRSmk=int
+aRSmC=Exception
+aRSmv=list
 from localstack import config
 from localstack.services.awslambda import lambda_executors
 from localstack.services.cloudformation.service_models import GenericBaseModel
@@ -14,13 +14,13 @@ from localstack.utils.testutil import map_all_s3_objects
 from localstack_ext.services.cloudformation.service_models import(CUSTOM_RESOURCE_STATUSES,CUSTOM_RESOURCES_RESULT_POLL_TIMEOUT,CUSTOM_RESOURCES_RESULTS_BUCKET,LOG)
 from localstack_ext.utils.aws import aws_utils
 class CDKMetadata(GenericBaseModel):
- @aftWx
+ @aRSmz
  def cloudformation_type():
   return "AWS::CDK::Metadata"
  def fetch_state(self,stack_name,resources):
   return{"type":"AWS::CDK::Metadata"}
 class CustomResource(GenericBaseModel):
- @aftWx
+ @aRSmz
  def cloudformation_type():
   return "AWS::CloudFormation::CustomResource"
  def fetch_state(self,stack_name,resources):
@@ -29,7 +29,7 @@ class CustomResource(GenericBaseModel):
   return result
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.logical_resource_id
- @aftWx
+ @aRSmz
  def get_deploy_templates():
   def create_custom_resource(resource_id,resources,resource_type,func,stack_name,*args):
    resource=resources[resource_id]
@@ -46,7 +46,7 @@ class CustomResource(GenericBaseModel):
    response_url=aws_stack.generate_presigned_url("put_object",Params={"Bucket":CUSTOM_RESOURCES_RESULTS_BUCKET,"Key":result_key},endpoint_url=endpoint_url)
    stack_arn=aws_stack.cloudformation_stack_arn(stack_name)
    request={"RequestType":"Create","ResponseURL":response_url,"StackId":stack_arn,"RequestId":short_uid(),"ResourceType":resource.get("Type"),"LogicalResourceId":resource_id,"ResourceProperties":resource_props}
-   if aftWC(service_token).startswith("arn:aws:lambda"):
+   if aRSme(service_token).startswith("arn:aws:lambda"):
     region_name=service_token.split(":")[3]
     function_name=aws_stack.lambda_function_name(service_token)
     lambda_client=aws_stack.connect_to_service("lambda",region_name=region_name)
@@ -56,13 +56,13 @@ class CustomResource(GenericBaseModel):
     return
    def fetch_result():
     return aws_utils.download_s3_object(CUSTOM_RESOURCES_RESULTS_BUCKET,result_key)
-   result=aftWL
+   result=aRSmB
    try:
-    result=retry(fetch_result,retries=aftWT(CUSTOM_RESOURCES_RESULT_POLL_TIMEOUT/2),sleep=2)
+    result=retry(fetch_result,retries=aRSmk(CUSTOM_RESOURCES_RESULT_POLL_TIMEOUT/2),sleep=2)
     result=json.loads(to_str(result))
-   except aftWY:
+   except aRSmC:
     bucket_objects=map_all_s3_objects(buckets=[CUSTOM_RESOURCES_RESULTS_BUCKET])
-    LOG.info("Unable to fetch CF custom resource result from s3://%s/%s . Existing keys: %s"%(CUSTOM_RESOURCES_RESULTS_BUCKET,result_key,aftWj(bucket_objects.keys())))
+    LOG.info("Unable to fetch CF custom resource result from s3://%s/%s . Existing keys: %s"%(CUSTOM_RESOURCES_RESULTS_BUCKET,result_key,aRSmv(bucket_objects.keys())))
     raise
    region=aws_stack.get_region()
    status=CUSTOM_RESOURCE_STATUSES[region]=CUSTOM_RESOURCE_STATUSES.get(region,{})
