@@ -1,30 +1,33 @@
-from localstack.services.cloudformation.service_models import GenericBaseModel
-cJsuK=str
-cJsuo=staticmethod
-cJsuH=None
-cJsuk=super
+from localstack.services.cloudformation.service_models import REF_ID_ATTRS,GenericBaseModel
+CmQrE=str
+CmQrI=staticmethod
+CmQrF=None
+CmQrB=super
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import select_attributes,short_uid
-def canonicalize_name(name:cJsuK)->cJsuK:
+def canonicalize_name(name:CmQrE)->CmQrE:
  if name[-1]!=".":
   return f"{name}."
  return name
 class Route53HostedZone(GenericBaseModel):
- @cJsuo
+ @CmQrI
  def cloudformation_type():
   return "AWS::Route53::HostedZone"
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("route53")
   result=client.list_hosted_zones()["HostedZones"]
-  result=[z for z in result if z["Name"]==canonicalize_name(self.props.get("Name"))]
-  return(result or[cJsuH])[0]
- def get_physical_resource_id(self,attribute=cJsuH,**kwargs):
+  canonical_name=canonicalize_name(self.props.get("Name"))
+  result=[z for z in result if z["Name"]==canonical_name]
+  return(result or[CmQrF])[0]
+ def get_physical_resource_id(self,attribute=CmQrF,**kwargs):
   return self.props.get("Id")
  def get_cfn_attribute(self,attribute_name):
   if attribute_name=="NameServers":
    return[self.props.get("Name")]
-  return cJsuk(Route53HostedZone,self).get_cfn_attribute(attribute_name)
- @cJsuo
+  if attribute_name in REF_ID_ATTRS:
+   return self.get_physical_resource_id()
+  return CmQrB(Route53HostedZone,self).get_cfn_attribute(attribute_name)
+ @CmQrI
  def get_deploy_templates():
   def _get_params(resource_props,resources,resource_id,*args,**kwargs):
    resource=Route53HostedZone(resources[resource_id])
