@@ -1,7 +1,7 @@
 from localstack.services.cloudformation.service_models import GenericBaseModel
-bpFjk=None
-bpFjs=classmethod
-bpFjr=staticmethod
+GwkJj=None
+GwkJH=classmethod
+GwkJn=staticmethod
 from localstack.utils.aws import aws_stack
 class ServiceDiscoveryNamespace(GenericBaseModel):
  def fetch_state(self,stack_name,resources):
@@ -9,10 +9,10 @@ class ServiceDiscoveryNamespace(GenericBaseModel):
   ns_name=self.resolve_refs_recursively(stack_name,self.props["Name"],resources)
   namespaces=client.list_namespaces()["Namespaces"]
   namespace=[ns for ns in namespaces if ns["Type"]==self._type()and ns["Name"]==ns_name]
-  return(namespace or[bpFjk])[0]
+  return(namespace or[GwkJj])[0]
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("Id")
- @bpFjs
+ @GwkJH
  def get_deploy_templates(cls):
   def delete_params(resource_props,resources,resource_id,**kwargs):
    resource=cls(resources[resource_id])
@@ -22,7 +22,7 @@ class ServiceDiscoveryNamespace(GenericBaseModel):
  def _type(self):
   raise
 class ServiceDiscoveryService(ServiceDiscoveryNamespace):
- @bpFjr
+ @GwkJn
  def cloudformation_type():
   return "AWS::ServiceDiscovery::Service"
  def fetch_state(self,stack_name,resources):
@@ -30,45 +30,45 @@ class ServiceDiscoveryService(ServiceDiscoveryNamespace):
   service_name=self.resolve_refs_recursively(stack_name,self.props["Name"],resources)
   services=client.list_services()["Services"]
   service=[s for s in services if s["Name"]==service_name]
-  return(service or[bpFjk])[0]
+  return(service or[GwkJj])[0]
  def get_physical_resource_id(self,attribute,**kwargs):
   if attribute=="Arn":
    return self.props.get("Arn")
   return self.props.get("Id")
- @bpFjs
+ @GwkJH
  def get_deploy_templates(cls):
   def delete_params(resource_props,resources,resource_id,**kwargs):
    resource=cls(resources[resource_id])
    return{"Id":resource.props.get("Id")}
   return{"create":{"function":"create_service"},"delete":{"function":"delete_service","parameters":delete_params}}
 class ServiceDiscoveryHttpNamespace(ServiceDiscoveryNamespace):
- @bpFjr
+ @GwkJn
  def cloudformation_type():
   return "AWS::ServiceDiscovery::HttpNamespace"
- @bpFjs
+ @GwkJH
  def _type(cls):
   return "HTTP"
- @bpFjs
+ @GwkJH
  def _create_function(cls):
   return "create_http_namespace"
 class ServiceDiscoveryPublicDnsNamespace(ServiceDiscoveryNamespace):
- @bpFjr
+ @GwkJn
  def cloudformation_type():
   return "AWS::ServiceDiscovery::PublicDnsNamespace"
- @bpFjs
+ @GwkJH
  def _type(cls):
   return "DNS_PUBLIC"
- @bpFjs
+ @GwkJH
  def _create_function(cls):
   return "create_public_dns_namespace"
 class ServiceDiscoveryPrivateDnsNamespace(ServiceDiscoveryNamespace):
- @bpFjr
+ @GwkJn
  def cloudformation_type():
   return "AWS::ServiceDiscovery::PrivateDnsNamespace"
- @bpFjs
+ @GwkJH
  def _type(cls):
   return "DNS_PRIVATE"
- @bpFjs
+ @GwkJH
  def _create_function(cls):
   return "create_private_dns_namespace"
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
